@@ -1,22 +1,9 @@
 /*
-    This file is part of kdev-python, the python language plugin for KDevelop
-    Copyright (C) 2012  Sven Brauch <svenbrauch@googlemail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "pdbframestackmodel.h"
 #include "debugsession.h"
 #include <QRegExp>
@@ -50,7 +37,7 @@ void PdbFrameStackModel::framesFetched(QByteArray framelist)
     QList<QByteArray> lines = framelist.split('\n');
     QList<FrameItem> frames;
     bool parsingLocation = false;
-    FrameItem* currentFrame = 0;
+    FrameItem* currentFrame = nullptr;
     int framesCount = 0;
     foreach ( const QString& line, lines ) {
         if ( line.startsWith("-> ") ) {
@@ -82,7 +69,8 @@ void PdbFrameStackModel::framesFetched(QByteArray framelist)
     }
     m_debuggerAtFrame = framesCount - m_debuggerAtFrame - 1;
     qCDebug(KDEV_PYTHON_DEBUGGER) << "at frame:" << m_debuggerAtFrame;
-    QList<FrameItem> framesReversed;
+    QVector<FrameItem> framesReversed;
+    framesReversed.reserve(frames.length());
     for ( int i = frames.length() - 1; i >= 0; i-- ) {
         framesReversed.append(frames.at(i));
         framesReversed.last().nr = framesCount - i - 2;
@@ -94,7 +82,7 @@ void PdbFrameStackModel::threadsFetched(QByteArray threadsData)
 {
     qCDebug(KDEV_PYTHON_DEBUGGER) << "threads fetched" << threadsData;
     qCDebug(KDEV_PYTHON_DEBUGGER) << "Implement me: Thread debugging is not supported by pdb.";
-    QList<ThreadItem> threads;
+    QVector<ThreadItem> threads;
     ThreadItem mainThread;
     mainThread.nr = 0;
     mainThread.name = "main thread";
